@@ -1,12 +1,15 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: adapter.py 918 2009-01-02 19:35:06Z mac $
+# $Id: adapter.py 997 2009-02-03 16:58:46Z mac $
 
 import zope.interface
 import zope.schema.interfaces
+import zope.location.interfaces
+import zope.site.hooks
 
 import icemac.addressbook.interfaces
+import icemac.addressbook.principals.interfaces
 
 
 @zope.interface.implementer(icemac.addressbook.interfaces.ITitle)
@@ -31,3 +34,9 @@ def default_title(obj):
     if isinstance(obj, basestring):
         return obj
     return str(obj)
+
+
+@zope.component.adapter(zope.interface.Interface)
+@zope.interface.implementer(icemac.addressbook.principals.interfaces.IRoot)
+def principal_root(principal):
+    return zope.site.hooks.getSite()
