@@ -1,12 +1,13 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: evolve2.py 913 2009-01-02 12:47:38Z mac $
+# $Id: evolve2.py 1001 2009-02-07 08:10:56Z mac $
 
 __docformat__ = "reStructuredText"
 
 import zope.app.generations.utility
 import zope.app.zopeappgenerations
+import zope.catalog.interfaces
 
 import icemac.addressbook.interfaces
 
@@ -16,8 +17,7 @@ generation = 2
 
 @icemac.addressbook.utils.set_site
 def fix_kexword_index():
-    catalog = zope.component.getUtility(
-        zope.app.catalog.interfaces.ICatalog)
+    catalog = zope.component.getUtility(zope.catalog.interfaces.ICatalog)
     catalog.updateIndex(catalog.get('keywords'))
 
 
