@@ -13,7 +13,7 @@
 ##############################################################################
 """Data Converters
 
-$Id: converter.py 93492 2008-12-01 16:50:04Z adamg $
+$Id: converter.py 97381 2009-02-28 12:26:20Z nadako $
 """
 __docformat__ = "reStructuredText"
 import datetime
@@ -81,6 +81,8 @@ def FieldWidgetDataConverter(widget):
 
 class FormatterValidationError(zope.schema.ValidationError):
 
+    message = None # redefine here, so Python 2.6 won't raise warning
+
     def __init__(self, message, value):
         zope.schema.ValidationError.__init__(self, message, value)
         self.message = message
@@ -284,6 +286,8 @@ class CollectionSequenceDataConverter(BaseDataConverter):
 
     def toWidgetValue(self, value):
         """Convert from Python bool to HTML representation."""
+        if value is self.field.missing_value:
+            return []
         widget = self.widget
         if widget.terms is None:
             widget.updateTerms()
@@ -318,17 +322,20 @@ class TextLinesConverter(BaseDataConverter):
         # if the value is the missing value, then an empty list is produced.
         if value is self.field.missing_value:
             return u''
-        return "\n".join(value)
+        return u'\n'.join(unicode(v) for v in value)
 
     def toFieldValue(self, value):
         """See interfaces.IDataConverter"""
         widget = self.widget
         collectionType = self.field._type
+        if isinstance(collectionType, tuple):
+            collectionType = collectionType[-1]
         if not len(value):
             return self.field.missing_value
         valueType = self.field.value_type._type
-        values = [valueType(v) for v in value.split()]
-        return collectionType(values)
+        if isinstance(valueType, tuple):
+            valueType = valueType[0]
+        return collectionType(valueType(v) for v in value.split())
 
 
 class MultiConverter(BaseDataConverter):
